@@ -24,7 +24,8 @@ import httpx
 _HOST = os.environ.get("APP_HOST", "localhost")
 _SCHEME = os.environ.get("APP_SCHEME", "http")
 _PORT = os.environ.get("APP_PORT", "8069")
-_ISSUER = os.environ.get("OIDC_SERVER_URL", "http://localhost:3000/")
+_ISSUER = os.environ.get("IDENTITY_PROVIDER_BASE_URL", "https://oak-identity-provider-oak-develop.test.services.jtech.se/")
+_POD_PROVIDER = os.environ.get("POD_PROVIDER_BASE_URL", "https://oak-pod-provider-oak-develop.test.services.jtech.se/")
 _OID_CALLBACK_PATH = os.environ.get("OIDC_CALLBACK_ENDPOINT", "/casemanagement/oauth/callback")
 
 
@@ -45,15 +46,18 @@ class SolidSession:
 
     @cached_property
     def provider_info(self):
-        return requests.get(_ISSUER + ".well-known/openid-configuration").json()
+        return requests.get(_ISSUER + ".well-known/openid-configuration",
+                            verify='/mnt/extra-addons/case_management/docker/cert.pem').json()
 
     @cached_property
     def solid_metadata(self):
-        return requests.get(_ISSUER + ".well-known/solid").json()
+        return requests.get(_ISSUER + ".well-known/solid",
+                            verify='/mnt/extra-addons/case_management/docker/cert.pem').json()
 
     @cached_property
     def idp_info(self):
-        return requests.get(_ISSUER + "idp/").json().get('controls')
+        return requests.get(_ISSUER + "idp/",
+                            verify='/mnt/extra-addons/case_management/docker/cert.pem').json().get('controls')
 
     def register_client(self):
         # Client registration.
@@ -148,25 +152,27 @@ class SolidSession:
         headers = self.make_headers(uri, method)
 
         if method == "GET":
-            resp = requests.get(uri, headers=headers)
+            resp = requests.get(uri, headers=headers, verify='/mnt/extra-addons/case_management/docker/cert.pem')
             auth_url = self.get_authorization_endpoint_uri()
             return SolidResponse(resp, self, auth_url=auth_url)
 
         elif method == "DELETE":
-            resp = requests.delete(uri, headers=headers)
+            resp = requests.delete(uri, headers=headers, verify='/mnt/extra-addons/case_management/docker/cert.pem')
 
             return SolidResponse(resp, self)
 
         # Is POST needed? Just PUT 4Head
         elif method == "POST":
             headers["Content-Type"] = content_type
-            resp = requests.post(uri, data=data, headers=headers)
+            resp = requests.post(uri, data=data, headers=headers,
+                                 verify='/mnt/extra-addons/case_management/docker/cert.pem')
 
             return SolidResponse(resp, self)
 
         elif method == "PUT":
             headers["Content-Type"] = content_type
-            resp = requests.put(uri, headers=headers, data=data)
+            resp = requests.put(uri, headers=headers, data=data,
+                                verify='/mnt/extra-addons/case_management/docker/cert.pem')
 
             return SolidResponse(resp, self)
 
@@ -271,10 +277,10 @@ class SolidAPIWrapper(SolidAPI):
 
         # client._add_token() to inject an existing token obtained by solidclient
         scopes = ["openid", "offline_access"]
-        token = {'access_token': access_token['access_token'],
+        token = {'access_token': access_token.get('access_token'),
                  'refresh_token': access_token.get('refresh_token'),
                  'idp': client.idp,
-                 'token_type': access_token['token_type'],
+                 'token_type': access_token.get('token_type'),
                  'scopes': scopes}
 
         if 'expires_at' in access_token:
